@@ -1,4 +1,14 @@
 # -*- coding: utf-8
+"""
+    pyboleto.bank.bradesco
+    ~~~~~~~~~~~~~~~~~~~~~~
+
+    Lógica para boletos do banco Bradesco.
+
+    :copyright: © 2011 - 2012 by Eduardo Cereto Carvalho
+    :license: BSD, see LICENSE for more details.
+
+"""
 from ..data import BoletoData, custom_property
 
 
@@ -37,10 +47,6 @@ class BoletoBradesco(BoletoData):
             dv = digito
         return dv
 
-    agencia_cedente = custom_property('agencia_cedente', 4)
-
-    conta_cedente = custom_property('conta_cedente', 7)
-
     @property
     def campo_livre(self):
         content = "%4s%2s%11s%7s%1s" % (self.agencia_cedente.split('-')[0],
